==> retro-data-structures-0.17.0.tar.gz: retro-data-structures-0.17.0/retro_data_structures/base_resource.py <==
from __future__ import annotations

import typing
import uuid

from construct import Construct, Container

from retro_data_structures.game_check import Game

if typing.TYPE_CHECKING:
    from retro_data_structures.asset_manager import AssetManager

AssetType = str
AssetId = typing.Union[int, uuid.UUID]
NameOrAssetId = typing.Union[str, AssetId]


class Dependency(typing.NamedTuple):
    type: AssetType
    id: AssetId


class BaseResource:
    _raw: Container
    target_game: Game
    asset_manager: AssetManager

    def __init__(self, raw: Container, target_game: Game, asset_manager: typing.Optional[AssetManager] = None):
        self._raw = raw
        self.target_game = target_game
        self.asset_manager = asset_manager

    @classmethod
    def construct_class(cls, target_game: Game) -> Construct:
        raise NotImplementedError()

    @classmethod
    def resource_type(cls) -> AssetType:
        raise NotImplementedError()

    @classmethod
    def parse(cls, data: bytes, target_game: Game,
              asset_manager: typing.Optional[AssetManager] = None) -> "BaseResource":
        return cls(cls.construct_class(target_game).parse(data, target_game=target_game),
                   target_game, asset_manager)

    def build(self) -> bytes:
        return self.construct_class(self.target_game).build(self._raw, target_game=self.target_game)

    def dependencies_for(self) -> typing.Iterator[Dependency]:
        raise NotImplementedError()

    @property
    def raw(self) -> Container:
        return self._raw


def resolve_asset_id(game: Game, value: NameOrAssetId) -> AssetId:
    if isinstance(value, str):
        value = game.hash_asset_id(value)

    if game.uses_guid_as_asset_id and isinstance(value, int):
        return uuid.UUID(int=value)

    return value


class RawResource(typing.NamedTuple):
    type: AssetType
    data: bytes

==> retro-data-structures-0.19.1.tar.gz: retro-data-structures-0.19.1/retro_data_structures/base_resource.py <==
from __future__ import annotations

import typing
import uuid

from construct import Construct, Container

if typing.TYPE_CHECKING:
    from retro_data_structures.asset_manager import AssetManager
    from retro_data_structures.game_check import Game

AssetType = str
AssetId = int | uuid.UUID
NameOrAssetId = str | AssetId


class Dependency(typing.NamedTuple):
    type: AssetType
    id: AssetId


class BaseResource:
    _raw: Container
    target_game: Game
    asset_manager: AssetManager

    def __init__(self, raw: Container, target_game: Game, asset_manager: typing.Optional[AssetManager] = None):
        self._raw = raw
        self.target_game = target_game
        self.asset_manager = asset_manager

    @classmethod
    def construct_class(cls, target_game: Game) -> Construct:
        raise NotImplementedError()

    @classmethod
    def resource_type(cls) -> AssetType:
        raise NotImplementedError()

    @classmethod
    def parse(cls, data: bytes, target_game: Game,
              asset_manager: typing.Optional[AssetManager] = None) -> "BaseResource":
        return cls(cls.construct_class(target_game).parse(data, target_game=target_game),
                   target_game, asset_manager)

    def build(self) -> bytes:
        return self.construct_class(self.target_game).build(self._raw, target_game=self.target_game)

    @classmethod
    def has_dependencies(cls, target_game: Game) -> bool:
        dummy = cls(Container(), target_game, None)
        try:
            return len(dummy.dependencies_for()) > 0
        except Exception:
            return True

    def dependencies_for(self, is_mlvl: bool = False) -> typing.Iterator[Dependency]:
        raise NotImplementedError()

    @property
    def raw(self) -> Container:
        return self._raw


def resolve_asset_id(game: Game, value: NameOrAssetId) -> AssetId:
    if isinstance(value, str):
        value = game.hash_asset_id(value)

    if game.uses_guid_as_asset_id and isinstance(value, int):
        return uuid.UUID(int=value)

    return value


class RawResource(typing.NamedTuple):
    type: AssetType
    data: bytes

Resource = RawResource | BaseResource
